bootstrap.BootstrapRecord

|  | ## Cheshire3 Object Model: Class BootstrapRecord

Module bootstrap :: Class BootstrapRecord

## Class BootstrapRecord
source code

Instance Methods

__init__(self, dom, xml)
get_dom(self)
get_xml(self)
get_sax(self)

Class Variables

xml |
dom |

Method Details

### __init__(self, dom, xml) (Constructor) | source code

### get_dom(self) | source code

### get_xml(self) | source code

### get_sax(self) | source code

Class Variable Details

    ### xml Value:
        ''

    ### dom Value:
        None